tonalitytools.make_all_notes_in_ascending_and_descending_diatonic_scale
=======================================================================

.. autofunction:: abjad.tools.tonalitytools.make_all_notes_in_ascending_and_descending_diatonic_scale.make_all_notes_in_ascending_and_descending_diatonic_scale
